@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2014 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -34,6 +34,7 @@
 #define GKRELLMD_H
 
 #include "log.h"
+#include "gkrellmd-version.h"
 
 #include <glib.h>
 #include <glib/gstdio.h>
@@ -106,17 +107,6 @@
 
 /* -------------------------------------------------------------------
 */
-#define GKRELLMD_VERSION_MAJOR   2
-#define GKRELLMD_VERSION_MINOR   3
-#define GKRELLMD_VERSION_REV     10
-#define GKRELLMD_EXTRAVERSION    ""
-//#define GKRELLMD_EXTRAVERSION    "-pre1"
-
-#define GKRELLMD_CHECK_VERSION(major,minor,rev)    \
-(GKRELLMD_VERSION_MAJOR > (major) || \
-(GKRELLMD_VERSION_MAJOR == (major) && GKRELLMD_VERSION_MINOR > (minor)) || \
-(GKRELLMD_VERSION_MAJOR == (major) && GKRELLMD_VERSION_MINOR == (minor) && \
-GKRELLMD_VERSION_REV >= (rev)))
 
 #define GKRELLMD_CONFIG				"gkrellmd.conf"
 #if defined(WIN32)
@@ -130,10 +120,9 @@ GKRELLMD_VERSION_REV >= (rev)))
 #if !defined(WIN32)
 	#define GKRELLMD_LOCAL_PLUGINS_DIR	"/usr/local/lib/gkrellm2/plugins-gkrellmd"
 	#if !defined(GKRELLMD_SYSTEM_PLUGINS_DIR)
-		#define GKRELLMD_SYSTEM_PLUGINS_DIR	"/usr/local/lib/gkrellm2/plugins-gkrellmd"
+		#define GKRELLMD_SYSTEM_PLUGINS_DIR	"/usr/lib/gkrellm2/plugins-gkrellmd"
 	#endif
-	#define GKRELLMD_SYS_ETC	"/etc"
-	#define GKRELLMD_LOCAL_ETC	"/etc"
+	#define GKRELLMD_SYS_ETC	"/usr/pkg/etc"
 #endif // !defined(WIN32)
 
 
@@ -227,12 +216,12 @@ void		gkrellmd_client_input_connect(GkrellmdMonitor *mon,
   */
 void		gkrellmd_free_glist_and_data(GList **list_head);
 gboolean	gkrellmd_getline_from_gstring(GString **, gchar *, gint);
-gchar		*gkrellmd_dup_token(gchar **string, gchar *delimeters);
+gchar		*gkrellmd_dup_token(gchar **string, gchar *delimiters);
 gboolean	gkrellmd_dup_string(gchar **dst, gchar *src);
 
 void		gkrellm_free_glist_and_data(GList **list_head);
 gboolean	gkrellm_getline_from_gstring(GString **, gchar *, gint);
-gchar		*gkrellm_dup_token(gchar **string, gchar *delimeters);
+gchar		*gkrellm_dup_token(gchar **string, gchar *delimiters);
 gboolean	gkrellm_dup_string(gchar **dst, gchar *src);
 
 
@@ -247,4 +236,4 @@ void		gkrellmd_add_mailbox(gchar *);
 GkrellmdTicks *gkrellmd_ticks(void);
 gint		gkrellmd_get_timer_ticks(void);
 
-#endif // GKRELLMD_H
+#endif
